$(function(){
    $('#loginBtn').click(function(){
        $('#loginBlock').fadeIn();
        return false;
    });
    $('.close_popup').click(function(){
        $(this).parent().parent().fadeOut();
        return false;
    });
});