<?php echo form_open('ajax/user/action/change_user_info', array('class' => 'form_register')) ?>
<div class="field-box">
    <label><?php echo $this->lang->line('Name'); ?></label>
    <input type="text" name="name" value="<?php echo $user->getCurrentUserData('name'); ?>"/>
</div>
<div class="field-box">
    <label><?php echo $this->lang->line('Surname'); ?></label>
    <input type="text" name="surname" value="<?php echo $user->getCurrentUserData('surname'); ?>"/>
</div>
<div class="field-box">
    <label><?php echo $this->lang->line('Sex'); ?></label>
    <?php echo form_dropdown('sex', array(2 => 'Female', 1 => 'Male'), $user->getCurrentUserData('sex')); ?>
</div>
<div class="field-box">
    <label><?php echo $this->lang->line('Phone'); ?></label>
    <input type="text" name="phone" value="<?php echo $user->getCurrentUserData('phone'); ?>"/>
</div>
<div class="checkbox-inline">                            
    <input type="checkbox" id="subscribe" name="subscribe" <?php echo ($user->getCurrentUserData('subscribe') ? 'checked="checked"' : '') ?> />
    <label class="check_label" for="subscribe"><?php echo $this->lang->line('Subscribe for news'); ?></label>
</div>
<div class="field-box">                            
    <input type="submit" class="big_orange" value="<?php echo $this->lang->line('Save') ?>" />
</div>
<?php echo form_close() ?>