<?php if ($message) : ?>
    <?php if ($error) : ?>
        <p class="error"><?php echo $this->lang->line('Email not found') ?></p>
    <?php else : ?>
        <p class="success"><?php echo $this->lang->line('In your Email sent a letter with a link to password-free login') ?></p>
    <?php endif; ?>
<?php endif; ?>

<?php echo form_open('ajax/user/action/forgot_password', array('class' => 'form_register')) ?>
<p class="form_desc"><?php echo $this->lang->line('Enter your E-mail') ?></p>
<div class="field-box">
    <label><?php echo $this->lang->line('E-mail') ?></label>
    <input type="email" name="email" value="{email}" required/>
</div>
<div class="field-box">                            
    <input type="submit" class="big_orange" value="<?php echo $this->lang->line('Recovery') ?>" />
</div>
<?php echo form_close() ?>