<?php if ($message) : ?>
    <p class="success">{message}</p>
<?php endif; ?>
<?php echo form_open('', array('class' => 'form_register')) ?>
<div class="field-box">
    <label><?php echo $this->lang->line('Current password') ?></label>
    <input type="password" name="oldpass" value="" required />
    <?php echo form_error('oldpass', '<p class="error">'); ?>
</div>
<div class="field-box">
    <label><?php echo $this->lang->line('New password') ?></label>
    <input type="password" name="password" value="" required />
    <?php echo form_error('password', '<p class="error">'); ?>
</div>
<div class="field-box">
    <label><?php echo $this->lang->line('New password again') ?></label>
    <input type="password" name="passconf" value="" required />
    <?php echo form_error('passconf', '<p class="error">'); ?>
</div>
<div class="field-box">                            
    <input type="submit" class="big_orange" value="<?php echo $this->lang->line('Change password') ?>" />
    <a href="" class="cancel_link"><?php echo $this->lang->line('Cancel') ?></a>
</div>
<?php echo form_close() ?>